@@ -1,6 +1,7 @@
 import unittest
 
 from pythautomata.automata_definitions.weighted_tomitas_grammars import WeightedTomitasGrammars
+from pythautomata.model_comparators.wfa_comparison_strategy import WFAComparator as PDFAComparator
 
 from pymodelextractor.learners.observation_table_learners.pdfa_lstarcol_learner import PDFALStarColLearner
 from pymodelextractor.teachers.pdfa_teacher import PDFATeacher
@@ -13,7 +14,7 @@ class TestPDFALStarColLearner(unittest.TestCase):
 
     def test_tomitas_1(self):
         model = WeightedTomitasGrammars.get_automaton_1()
-        teacher = PDFATeacher(model, 0)
+        teacher = PDFATeacher(model, 0, PDFAComparator())
         result = self.learner.learn(teacher)
         extracted_model = result.model
         self.assertEqual(model, extracted_model)
@@ -22,16 +23,16 @@ class TestPDFALStarColLearner(unittest.TestCase):
 
     def test_tomitas_2(self):
         model = WeightedTomitasGrammars.get_automaton_2()
-        teacher = PDFATeacher(model, 0)
+        teacher = PDFATeacher(model, 0, PDFAComparator())
         result = self.learner.learn(teacher)
         extracted_model = result.model
-        self.assertEqual(model, extracted_model)
+        self.assertEqual(model, extracted_model, PDFAComparator())
         self.assertTrue(result.info['last_token_weight_queries_count']>0)        
         self.assertTrue(result.info['equivalence_queries_count']>0)
 
     def test_tomitas_3(self):
         model = WeightedTomitasGrammars.get_automaton_3()
-        teacher = PDFATeacher(model, 0)
+        teacher = PDFATeacher(model, 0, PDFAComparator())
         result = self.learner.learn(teacher)
         extracted_model = result.model
         self.assertEqual(model, extracted_model)
@@ -40,7 +41,7 @@ class TestPDFALStarColLearner(unittest.TestCase):
 
     def test_tomitas_4(self):
         model = WeightedTomitasGrammars.get_automaton_4()
-        teacher = PDFATeacher(model, 0)
+        teacher = PDFATeacher(model, 0, PDFAComparator())
         result = self.learner.learn(teacher)
         extracted_model = result.model
         self.assertEqual(model, extracted_model)
@@ -49,7 +50,7 @@ class TestPDFALStarColLearner(unittest.TestCase):
 
     def test_tomitas_5(self):
         model = WeightedTomitasGrammars.get_automaton_5()
-        teacher = PDFATeacher(model, 0)
+        teacher = PDFATeacher(model, 0, PDFAComparator())
         result = self.learner.learn(teacher)
         extracted_model = result.model
         self.assertEqual(model, extracted_model)
@@ -58,7 +59,7 @@ class TestPDFALStarColLearner(unittest.TestCase):
 
     def test_tomitas_6(self):
         model = WeightedTomitasGrammars.get_automaton_6()
-        teacher = PDFATeacher(model, 0)
+        teacher = PDFATeacher(model, 0, PDFAComparator())
         result = self.learner.learn(teacher)
         extracted_model = result.model
         self.assertEqual(model, extracted_model)
@@ -67,7 +68,7 @@ class TestPDFALStarColLearner(unittest.TestCase):
 
     def test_tomitas_7(self):
         model = WeightedTomitasGrammars.get_automaton_7()
-        teacher = PDFATeacher(model, 0)
+        teacher = PDFATeacher(model, 0, PDFAComparator())
         result = self.learner.learn(teacher)
         extracted_model = result.model
         self.assertEqual(model, extracted_model)
